package com.cntaiping.intserv.datasync;

import java.util.Date;
import java.util.List;

import com.cntaiping.intserv.basic.auth.user.ISUser;
import com.cntaiping.intserv.basic.runtime.db.page.ListPage;
import com.cntaiping.intserv.datasync.bmodel.EisNoticeBO;
import com.cntaiping.mobile.basic.ResultBO;

/**
 * 
 * 消息接口
 * 
 * @author YueLiang
 * @version 1.0
 * @createTime 2013-10-19
 */
public interface NoticeInterface {

	/**
	 * 获取广播消息
	 * 
	 * @param sendTimeBoard
	 * @param ptid
	 * @return
	 */
	public ResultBO loadNoticeBoardJSON(int ptid, Long recvOrgan,
			Long recvChannel);

	/**
	 * 获取广播消息(带时间戳)
	 * 
	 * @param sendTimeBoard
	 * @param ptid
	 * @return
	 */
	public ResultBO loadNoticeBoardInfo(String sendTimeIndivid, int ptid,
			String recvOrgan, String recvChannel, String userid);

	/**
	 * 根据用户类别获取广播消息(带时间戳)
	 * 
	 * @param sendTimeBoard
	 * @param ptid
	 * @return
	 */
	public ResultBO loadNoticeBoardInfoByUserCate(String sendTimeIndivid, int ptid,
			 String recvChannel, ISUser isUser);
	
	/**
	 * 获取个人消息
	 * 
	 * @param sendTimeIndivid
	 * @param recvUser
	 * @return
	 */
	public ResultBO loadNoticeIndividJSON(String sendTimeIndivid,
			String recvUser, int ptid);

	/**
	 * 批量更新个人消息表中的消息接收时间
	 * 
	 * @param rowsToUpdate
	 * @return
	 */
	public String updateRecvTimeJASON(String noticeIds);

	/**
	 * 批量更新个人消息表中的消息接收时间
	 * 
	 * @param rowsToUpdate
	 * @return
	 */
	public String updateRecvTimeJASON(String noticeIds, String recvUser,
			String userCate);

	/**
	 * 根据主键修改消息的请求类型(撤销消息)
	 * 
	 * @param noticeId
	 *            消息的id
	 * @param operateType
	 *            消息的请求类型 1-新建 2-撤销 3-阅读
	 * @return
	 * @throws Exception
	 */
	public String updateNoticeOperateType(Long noticeId, String operateType);

	/**
	 * 根据消息的发送流水修改请求类型
	 * 
	 * @param rawSeqId
	 *            消息的发送流水
	 * @param operateType
	 *            消息的请求类型 1-新建 2-撤销 3-阅读
	 * @return
	 * @throws Exception
	 */
	public String uptOprTypeByRawSeqId(String rawSeqId, String operateType);

	/**
	 * 删除消息
	 * 
	 * @param type
	 *            0 广播消息 1 个人消息
	 * @param noticeId
	 *            消息id
	 * @return
	 */
	public String deleteNotice(String type, String noticeId);

	/**
	 * 删除消息
	 * 
	 * @param type
	 *            0 广播消息 1 个人消息
	 * @param noticeId
	 *            消息id
	 * @param recvUser
	 *            业务员id
	 * @return
	 */
	public String deleteNotice(String type, String noticeId, String recvUser,
			String userCate);

	/**
	 * 批量删除消息
	 * 
	 * @param type
	 *            0 广播消息 1 个人消息
	 * @param rowsToUpdate
	 *            JASON
	 * @return
	 */
	public String batchDeleteNoticeJASON(String type, String rowsToUpdate);

	public ResultBO loadNoticeIndividJSON(String sendTimeIndivid,
			String recvUser, int source, String userCate);

	/**
	 * 根据消息批次号获取消息明细
	 * 
	 * @param batchNo
	 *            消息批次号
	 * @return
	 */
	public ResultBO loadNoticeForBatchNo(Long batchNo);

	/**
	 * 根据消息的批次号撤销消息发送
	 * 
	 * @param batchNo消息批次号
	 * @param type
	 *            消息发送类型 1：消息 2：短信
	 * @return
	 */
	public String updateNoticeIndividStatus(Long batchNo, int type);
	
	/**
	 * 带分页的消息查询接口
	 * @param recvUser  接收人
	 * @param startDate
	 * @param endDate
	 * @param noticeCate 消息类型
	 * @param noticeSource 消息来源
	 * @param noticeType 消息类型
	 * @param pageNo 
	 * @param pageSize 
	 * @return
	 */
	public ListPage queryNoticeInfoPage(String recvUser,Date startDate, Date endDate, String noticeCate, int noticeSource, int noticeType, int pageNo, int pageSize);

	/**
	 * 根据主键修改消息的收藏锁定
	 * 
	 * @param noticeId
	 *            消息的id
	 * @param favorite
	 *            收藏锁定 
	 * @return
	 * @throws Exception
	 */
	public String updateNoticeFavoriteType(Long noticeId, String favorite);

	/**
	 * 获取用户的消息唯一识别码 Message Unique identification code，根据此MUID可以查询到该用户的所有消息
	 * 生成规则 （userSource_organId_userId）
	 * @param noticeSource 消息来源
	 * @param userSource 用户来源
	 * @param organId 机构id
	 * @param userId 用户id
	 * @return MUID 消息唯一识别码
	 */
	public String getUserMUID(String noticeSource, String userSource, String organId, String userId);

	/**
	 * 获取消息查询时的轮循时间表
	 * @param noticeSource 平台
	 * @return 结果集
	 */
	public ResultBO getNoticeIntervalTimeSchedule(String noticeSource);

	/**
	 * 根据muid 获取该用户的个人消息
	 * @param muid  用户消息唯一识别码
	 * @param lastNoticeSendTime 移动端本地数据库中最近一条消息的入库时间。
	 * @param noticeSource 消息平台
	 * @param lastImportantTime 上次‘关键事件’触发的时间点
	 * @return 消息结果集
	 */
	public ResultBO loadNoticeIndividByMUID(String muid, Long lastNoticeSendTime, String noticeSource, Long lastImportantTime);

	/**
	 * 查询所有的历史消息(最大3个月以内的数据)
	 * @param muid 用户消息唯一识别码
	 * @param currentQueryTimes 当天的‘本次查询次数’
	 * @return 消息结果集
	 */
	public ResultBO loadAllNoticeIndividByMUID(String muid, Integer currentQueryTimes);

	/**
	 * 更新个人消息的状态为‘已读’
	 * @param muid 用户消息唯一识别码
	 * @param noticeIdList 消息id（主键）列表
	 * @return 是否成功 success failed
	 */
	public String updateNoticeIndividOprTypeToRead(String muid, List noticeIdList);

	/**
	 * 移除消息缓存
	 * @param muid 用户消息唯一识别码
	 * @return 是否成功 success failed
	 */
	public String removeNoticeCache(String muid);

	/**
	 * 获取所有的缓存key
	 * @return 结果集
	 */
	public ResultBO listAllCacheKey();
}
