package com.cntaiping.intserv.datasync.service;

import java.math.BigDecimal;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.apache.log4j.Logger;

import com.cntaiping.intserv.basic.auth.user.ISUser;
import com.cntaiping.intserv.basic.runtime.db.DBUtil;
import com.cntaiping.intserv.datasync.bmodel.EisNoticeBO;

/**
 * 广播消息
 * 
 * @createTime 2013-9-23
 * @author ZhangYongJie
 * 
 * 
 */
public class EisNoticeBoardBean {
	private static Logger logger = Logger.getLogger(EisNoticeBoardBean.class);

	public static List<EisNoticeBO> loadAll(int ptid, Long recvOrgan,
			Long recvChannel) throws Exception {
		logger.info("EisNoticeBoardBean loadAll()recvOrgan:" + recvOrgan
				+ " recvChannel:" + recvChannel);
		PreparedStatement pst = null;
		ResultSet rs = null;
		String sql = null;
		Connection conn = DBUtil.getConnection();
		List<EisNoticeBO> list = new ArrayList<EisNoticeBO>();

		try {
			sql = "SELECT NOTICE_ID, NOTICE_CATE, NOTICE_SOURCE, NOTICE_TITLE, NOTICE_CONTENT,NOTICE_TITLE_DESC,IS_HAVE_DETAILS,IS_NEED_INFORM,COVER_NOTICE_ID,NOTICE_DESC, "
					+ " BGN_TIME, END_TIME, SEND_USER, SEND_TIME, RECV_ORGAN, RECV_BRANCH, RECV_CHANNEL,SEND_USER_NAME,REMARK,recv_user "
					+ " FROM EIS_NOTICE_BOARD WHERE BGN_TIME <= SYSDATE AND END_TIME >= SYSDATE  "
					+ " AND RECV_ORGAN IN (SELECT TBL.ORGAN_ID FROM TBL_MD_ORGANAZITION TBL START WITH TBL.ORGAN_ID = ? CONNECT BY TBL.ORGAN_ID = PRIOR TBL.PARENT_ID)"
					+ " AND RECV_CHANNEL = ?  ORDER BY SEND_TIME";
			pst = conn.prepareStatement(sql);
			pst.setString(1, String.valueOf(recvOrgan));
			pst.setLong(2, recvChannel);
			logger.info("sql:" + sql);
			rs = pst.executeQuery();
			EisNoticeBO bo = null;
			while (rs.next()) {
				bo = fetch(rs);
				if (null != bo) {
					list.add(bo);
				}
			}
		} catch (Exception e) {
			logger.error("EisNoticeBoardBean loadAll() Error", e);
			throw e;
		} finally {
			DBUtil.close(rs, pst, conn);
		}
		return list;
	}

	// 获取广播消息（带时间戳）
	public static List<EisNoticeBO> loadBoardAll(Timestamp timestamp, int ptid,
			String recvOrgan, String recvChannel, String userid)
			throws Exception {
		logger.info("EisNoticeBoardBean loadAll()recvOrgan:" + recvOrgan
				+ " recvChannel:" + recvChannel);
		PreparedStatement pst = null;
		ResultSet rs = null;
		String sql = null;
		Connection conn = DBUtil.getConnection();
		List<EisNoticeBO> list = new ArrayList<EisNoticeBO>();

		try {
			sql = " select  c.NOTICE_ID,c.NOTICE_CATE, c.NOTICE_SOURCE,c.NOTICE_TITLE, c.NOTICE_CONTENT,c.NOTICE_TITLE_DESC,c.IS_HAVE_DETAILS,c.IS_NEED_INFORM,c.COVER_NOTICE_ID,";
			sql += "c.NOTICE_DESC,c.BGN_TIME,c.END_TIME, c.SEND_USER,c.SEND_TIME,c.RECV_ORGAN, c.RECV_BRANCH,";
			sql += "c.RECV_CHANNEL, c.SEND_USER_NAME, c.REMARK,c.recv_user, ";
			sql += "case  c.oper_type ";
			sql += "  when 0 then '1' ";
			sql += " else '3' end  oper_type";
			sql += " from   ";
			sql += " (SELECT a.*,(select count(*) from eis_notice_board_user u where a.notice_id = u.notice_id  and u.user_id = ?)  oper_type";
			sql += " FROM EIS_NOTICE_BOARD a";
			sql += " WHERE BGN_TIME <= SYSDATE";
			sql += "  AND END_TIME >= SYSDATE";
			sql += " AND RECV_CHANNEL = ? ";
			sql += " AND SEND_TIME >= ? ";
			sql += " AND NOTICE_SOURCE = ?";
			// sql
			// +=" AND RECV_ORGAN IN (SELECT TBL.ORGAN_ID FROM TBL_MD_ORGANAZITION TBL START WITH TBL.ORGAN_ID = ? CONNECT BY TBL.ORGAN_ID = PRIOR TBL.PARENT_ID)";
			sql += " ORDER BY a.SEND_TIME) c";
			sql += "  ORDER BY c.SEND_TIME";

			pst = conn.prepareStatement(sql);
			pst.setString(1, userid);
			pst.setString(2, recvChannel);
			pst.setTimestamp(3, timestamp);
			pst.setInt(4, ptid);
			// pst.setString(5, recvOrgan);

			rs = pst.executeQuery();
			logger.info("sql=" + sql);
			EisNoticeBO bo = null;
			while (rs.next()) {
				bo = fetch(rs);
				if (null != bo) {
					if(bo.getNoticeCate() == 14){
						bo.setNoticeContent(bo.getNoticeContent()+"?userId="+userid);
					}
					list.add(bo);
				}
			}
		} catch (Exception e) {
			logger.error("EisNoticeBoardBean loadAll() Error", e);
			throw e;
		} finally {
			DBUtil.close(rs, pst, conn);
		}
		return list;
	}
	
	// 根据用户类别获取广播消息（带时间戳）
	public static List<EisNoticeBO> loadBoardAll(Timestamp timestamp, int ptid,
			String recvChannel,ISUser isUser)
			throws Exception {
		//如果机构为空，不发送消息
		if(isUser.getOrganId() == null || "".equals(isUser.getOrganId())){
			return null;
		}
		logger.info("EisNoticeBoardBean loadAll()recvOrgan:" + isUser.getOrganId()
				+ " recvChannel:" + recvChannel);
		if(!isNumeric(isUser.getOrganId())){//如果机构id不为数字，不发送消息
			return null;
		}
		
		PreparedStatement pst = null;
		ResultSet rs = null;
		String sql = null;
		Connection conn = null;
		List<EisNoticeBO> list = new ArrayList<EisNoticeBO>();
		
		
		/* 根据userCate和organID来查询消息
		 * userCate   organID      消息发送目标
		 *    空 			 空		           全体用户
		 *    空		         不空	           某个机构下的全体用户
		 *   不空	 	 空		   某种用户类型的用户
		 *   不空	         不空       某个机构下的某种用户类型的用户
		 */
		String userCate = isUser.getUserCate();
		String newOrganID = "";
		logger.info("---------userCate: "+userCate+" organID: "+isUser.getOrganId());
		if(isUser.getOrganId().length() > 3){
			newOrganID = isUser.getOrganId().substring(0, 3);
		}else if("1".equals(isUser.getOrganId())){//查询所有
			userCate = "";
		}else{
			newOrganID = isUser.getOrganId();
		}
		
		//特殊用户 产销以D结尾  中石化以C结尾 后续可能新增特殊用户
		if("104".equals(userCate) && isUser.getRawStaffCode() != null){
			if(isUser.getRawStaffCode().endsWith("C")){
				if("1".equals(recvChannel)){
					userCate = "999";
				}else{
					userCate = "888";
				}
			}
			if(isUser.getRawStaffCode().endsWith("D")){
				if("1".equals(recvChannel)){
					userCate = "777";
				}else{
					userCate = "666";
				}
			}
		}
		
		try {
			sql = " select  c.NOTICE_ID,c.NOTICE_CATE, c.NOTICE_SOURCE,c.NOTICE_TITLE, c.NOTICE_CONTENT,c.NOTICE_TITLE_DESC,c.IS_HAVE_DETAILS,c.IS_NEED_INFORM,c.COVER_NOTICE_ID,";
			sql += "c.NOTICE_DESC,c.BGN_TIME,c.END_TIME, c.SEND_USER,c.SEND_TIME,c.RECV_ORGAN, c.RECV_BRANCH,";
			sql += "c.RECV_CHANNEL, c.SEND_USER_NAME, c.REMARK,c.recv_user, ";
			sql += "case  c.oper_type ";
			sql += "  when 0 then '1' ";
			sql += " else '3' end  oper_type";
			sql += " from   ";
			sql += " (SELECT a.*,(select count(*) from eis_notice_board_user u where a.notice_id = u.notice_id  and u.user_id = ?)  oper_type";
			sql += " FROM EIS_NOTICE_BOARD a";
			sql += " WHERE BGN_TIME <= SYSDATE";
			sql += "  AND END_TIME >= SYSDATE";
			sql += " AND RECV_CHANNEL = ? ";
			sql += " AND SEND_TIME >= ? ";
			sql += " AND NOTICE_SOURCE = ? ";
			
			if (newOrganID != null && !"".equals(newOrganID)) {
				sql += " AND (recv_organ = ? or recv_organ is null)";
			}
			// sql
			// +=" AND RECV_ORGAN IN (SELECT TBL.ORGAN_ID FROM TBL_MD_ORGANAZITION TBL START WITH TBL.ORGAN_ID = ? CONNECT BY TBL.ORGAN_ID = PRIOR TBL.PARENT_ID)";
			sql += " ORDER BY a.SEND_TIME) c ";
			if (userCate != null && !"".equals(userCate)) {
				sql += " WHERE c.user_cate = ? OR c.user_cate is null ";
			}
			//sql += "OR RECV_USER = ?";
			sql += "  ORDER BY c.SEND_TIME";
			conn = DBUtil.getConnection();
			pst = conn.prepareStatement(sql);
			pst.setString(1, isUser.getUserId());
			pst.setString(2, recvChannel);
			pst.setTimestamp(3, timestamp);
			pst.setInt(4, ptid);
			
			// pst.setString(5, recvOrgan);
			if (newOrganID != null && !"".equals(newOrganID)) {
				pst.setString(5, newOrganID);
				if (userCate != null && !"".equals(userCate)) {
					pst.setString(6, userCate);
				}
			} else {
				if (userCate != null && !"".equals(userCate)) {
					pst.setString(5, userCate);
				}
			}
			
			logger.info("------------"+"isUser: "+isUser.getUserId()+"timestamp："+timestamp +"ptid: "+ptid +"newOrganID: "+newOrganID +"userCate: "+userCate);
			rs = pst.executeQuery();
			
			logger.info("sql=" + sql);
			EisNoticeBO bo = null;
			while (rs.next()) {
				bo = fetch(rs);
				if (null != bo) {
					if(bo.getNoticeCate() == 14){
						bo.setNoticeContent(bo.getNoticeContent()+"?userId="+isUser.getUserId());
					}
					if(isUser.getUserId().equals(bo.getRecvUser()) || "".equals(bo.getRecvUser())){
						list.add(bo);
					}
				}
			}
		} catch (Exception e) {
			logger.error("EisNoticeBoardBean loadAll() Error", e);
			throw e;
		} finally {
			DBUtil.close(rs, pst, conn);
		}
		return list;
	}
	
	/**
     * 匹配是否为数字
     * @param str 
     * @return
     * @author 
     * @date 
     */
    public static boolean isNumeric(String str) {
        // 该正则表达式可以匹配所有的数字
        Pattern pattern = Pattern.compile("-?[0-9]+(\\.[0-9]+)?");
        String bigStr;
        try {
            bigStr = new BigDecimal(str).toString();
        } catch (Exception e) {
            return false;//异常 说明包含非数字。
        }

        Matcher isNum = pattern.matcher(bigStr); // matcher是全匹配
        if (!isNum.matches()) {
            return false;
        }
        return true;
    }	

	private static EisNoticeBO fetch(ResultSet rs) throws Exception {
		EisNoticeBO bo = new EisNoticeBO();

		// 广播消息ID  2019/01/15改成产品通消息表里的notice_id
		if (!isEmpty(rs.getLong("COVER_NOTICE_ID"))) {
			bo.setNoticeId(rs.getLong("COVER_NOTICE_ID"));
		} else {
			bo.setNoticeId(null);
		}
		// 消息类别
		if (!isEmpty(rs.getString("NOTICE_CATE"))) {
			bo.setNoticeCate(Long.valueOf(rs.getString("NOTICE_CATE")));
		} else {
			bo.setNoticeCate(null);
		}
		// 消息来源
		if (!isEmpty(rs.getString("NOTICE_SOURCE"))) {
			bo.setNoticeSource(Long.valueOf(rs.getString("NOTICE_SOURCE")));
		} else {
			bo.setNoticeSource(null);
		}
		// 消息主题
		bo.setNoticeTitle(rs.getString("NOTICE_TITLE"));
		// 消息内容
		bo.setNoticeContent(rs.getString("NOTICE_CONTENT"));
		// 消息说明
		bo.setNoticeDesc(rs.getString("NOTICE_DESC"));
		// 广播开始时间
		if (!isEmpty(rs.getTimestamp("BGN_TIME"))) {
			bo.setBgnTime(rs.getTimestamp("BGN_TIME"));
		} else {
			bo.setBgnTime(null);
		}
		// 广播结束时间
		if (!isEmpty(rs.getTimestamp("END_TIME"))) {
			bo.setEndTime(rs.getTimestamp("END_TIME"));
		} else {
			bo.setEndTime(null);
		}
		// 发送人员
		if (null != rs.getString("SEND_USER")) {
			bo.setSendUser(rs.getString("SEND_USER"));
		} else {
			bo.setSendUser(null);
		}
		// 发送时间
		if (!isEmpty(rs.getTimestamp("SEND_TIME"))) {
			bo.setSendTime(rs.getTimestamp("SEND_TIME"));
		} else {
			bo.setSendTime(null);
		}
		// 接收机构
		if (!isEmpty(rs.getString("RECV_ORGAN"))) {
			bo.setRecvOrgan(Long.valueOf(rs.getString("RECV_ORGAN")));
		} else {
			bo.setRecvOrgan(null);
		}
		// 接收下属机构
		if (!isEmpty(rs.getString("RECV_BRANCH"))) {
			bo.setRecvBranch(Long.valueOf(rs.getString("RECV_BRANCH")));
		} else {
			bo.setRecvBranch(null);
		}
		// 接收渠道
		if (!isEmpty(rs.getString("RECV_CHANNEL"))) {
			bo.setRecvChannel(Long.valueOf(rs.getString("RECV_CHANNEL")));
		} else {
			bo.setRecvChannel(null);
		}
		// 发送人员名称
		if (null != rs.getString("SEND_USER_NAME")) {
			bo.setSendUserName(rs.getString("SEND_USER_NAME"));
		} else {
			bo.setSendUserName(null);
		}
		// 备注
		if (null != rs.getString("REMARK")) {
			bo.setRemark(rs.getString("REMARK"));
		} else {
			bo.setRemark(null);
		}
		// 请求类型 1-新建;2-撤销;3-阅读
		if (null != rs.getString("OPER_TYPE")) {
			bo.setOperateType(rs.getString("OPER_TYPE"));
		} else {
			bo.setOperateType(null);
		}
		//用户ID
		if (rs.getString("RECV_USER") != null && !"".equals(rs.getString("RECV_USER"))) {
			bo.setRecvUser(rs.getString("RECV_USER"));
		} else {
			bo.setRecvUser("");
		}
		//消息标题说明
		if (!isEmpty(rs.getString("NOTICE_TITLE_DESC"))) {
			bo.setNoticeTitleDesc(rs.getString("NOTICE_TITLE_DESC"));
		} else {
			bo.setNoticeTitleDesc("");
		}	
		//是否有详情
		if (!isEmpty(rs.getString("IS_HAVE_DETAILS"))) {
			bo.setIsHaveDetails(rs.getString("IS_HAVE_DETAILS"));
		} else {
			bo.setIsHaveDetails("");
		}	
		//是否需要通知
		if (!isEmpty(rs.getString("IS_NEED_INFORM"))) {
			bo.setIsNeedInform(rs.getString("IS_NEED_INFORM"));
		} else {
			bo.setIsNeedInform("");
		}		
		return bo;
	}

	public static boolean isEmpty(Object oj) {
		if (null == oj || "".equals(oj)) {
			return true;
		} else {
			return false;
		}
	}

}
