package com.cntaiping.intserv.datasync.service;

import java.sql.*;
import java.util.*;
import java.util.Date;

import com.cntaiping.intserv.datasync.bmodel.EisNoticeIntervalBO;
import org.apache.log4j.Logger;

import com.cntaiping.intserv.basic.runtime.db.DBUtil;
import com.cntaiping.intserv.basic.runtime.db.page.ListPage;
import com.cntaiping.intserv.basic.runtime.db.page.PagedStatement;
import com.cntaiping.intserv.datasync.bmodel.EisNoticeBO;

/**
 * 个人消息表bean
 * 
 * @author ZhangYongJie
 * 
 */
public class EisNoticeIndividBean {
	private static Logger logger = Logger.getLogger(EisNoticeIndividBean.class);

	/**
	 * 增量获取所有个人消息
	 * 
	 * @param Timestamp
	 *            sendTimeIndivid 发送时间
	 * @param String
	 *            recvUser 接收人
	 * @param int source 消息来源
	 * @return
	 * @throws Exception
	 */
	public static List<EisNoticeBO> loadAll(Timestamp sendTimeIndivid,
			String recvUser, int source) throws Exception {
		logger.info("sendTimeIndivid=" + sendTimeIndivid + " recvUser= "+ recvUser + " source= "+source);
		PreparedStatement pst = null;
		ResultSet rs = null;
		String sql = null;
		Connection conn = DBUtil.getConnection();
		List<EisNoticeBO> list = new ArrayList<EisNoticeBO>();
		try {

			sql = "SELECT NOTICE_ID, NOTICE_CATE, NOTICE_SOURCE, NOTICE_TITLE, NOTICE_CONTENT, SEND_USER, SEND_TIME, RECV_USER, RECV_TIME, REMARK, OPERATE_TYPE, RAW_SEQ_ID, SEND_USER_CATE, RECV_USER_CATE, SCHEDULE_SEND_TIME, SEND_USER_NAME, RECV_USER_NAME,BATCH_NO,NOTICE_FAVORITE,NOTICE_TITLE_DESC,IS_HAVE_DETAILS,IS_NEED_INFORM, MUID, IS_NEED_UPDATE, NOTIFICATION_TYPE, NOTICE_DESC "
					+ " from EIS_NOTICE_INDIVID "
					+ " where OPERATE_TYPE IN('1','3') and (SCHEDULE_SEND_TIME<=SYSDATE AND SEND_TIME >= ? )  AND RECV_USER = ? ";
			if (22 == source || 23 == source || 24 == source) {
				sql += " and NOTICE_SOURCE = ? ";
			}
			sql += "  ORDER BY operate_type,SCHEDULE_SEND_TIME desc   ";
			pst = conn.prepareStatement(sql);
			pst.setTimestamp(1, sendTimeIndivid);
			
			pst.setString(2, recvUser);
			if (22 == source || 23 == source || 24 == source) {
				pst.setInt(3, source);
			}
			rs = pst.executeQuery();
			EisNoticeBO bo = null;
			while (rs.next()) {
				bo = fetch(rs);
				if (null != bo) {
					list.add(bo);
				}
			}
		} catch (Exception e) {
			logger.error("EisNoticeIndividBean loadAll(RECV_USER=" + recvUser
					+ ") Error", e);
			throw e;
		} finally {
			DBUtil.close(rs, pst, conn);
		}
		return list;
	}

	/**
	 * 带分页的消息查询接口
	 * 
	 * @param userId
	 * @param noticeCate
	 * @param noticeSource
	 * @param noticeType
	 * @param pageNo
	 * @param pageSize
	 * @return
	 * @throws Exception
	 */
	public static ListPage loadAllPage(String recvUser, Date startDate,
			Date endDate, String noticeCate, int noticeSource, int pageNo,
			int pageSize) throws Exception {
		ListPage listPage = null;
		PagedStatement pst = null;
		List<Object> parameterList = new ArrayList<Object>();
		StringBuffer sql = new StringBuffer();
		try {

			sql.append("SELECT NOTICE_ID, NOTICE_CATE, NOTICE_SOURCE, NOTICE_TITLE, NOTICE_CONTENT, SEND_USER, ");
			sql.append("SEND_TIME, RECV_USER, RECV_TIME, REMARK, OPERATE_TYPE, RAW_SEQ_ID, SEND_USER_CATE,  ");
			sql.append("RECV_USER_CATE, SCHEDULE_SEND_TIME, SEND_USER_NAME, RECV_USER_NAME, BATCH_NO, NOTICE_FAVORITE ");
			sql.append("from EIS_NOTICE_INDIVID ");
			sql.append("where 1 = 1 ");
			if (recvUser != null && !"".equals(recvUser)) {
				sql.append("AND RECV_USER = ? ");
				parameterList.add(recvUser);
			}
			if (startDate != null) {
				sql.append("AND SEND_TIME >= ? ");
				parameterList.add(new Timestamp(startDate.getTime()));
			}
			if (endDate != null) {
				sql.append("AND SEND_TIME <= ? ");
				parameterList.add(new Timestamp(endDate.getTime()));
			}
			if (noticeCate != null && !"".equals(noticeCate)) {
				sql.append("AND NOTICE_CATE = ? ");
				parameterList.add(Integer.parseInt(noticeCate));
			}
			if (22 == noticeSource || 23 == noticeSource || 24 == noticeSource) {
				sql.append("AND NOTICE_SOURCE = ? ");
				parameterList.add(noticeSource);
			}
			sql.append("ORDER BY SCHEDULE_SEND_TIME desc");
			pst = new PagedStatement(sql.toString(), pageNo, pageSize);
			int parameterFlag = 1;
			for (Object parameter : parameterList) {
				pst.setObject(parameterFlag++, parameter);
			}
			listPage = pst.executeQuery();
			logger.info(sql.toString());

		} catch (Exception e) {
			logger.error("EisNoticeIndividBean loadAllPage Error", e);
			throw e;
		}
		return listPage;
	}

	/**
	 * 根据消息批次号获取消息明细
	 * 
	 * @param batchNo
	 *            消息批次号
	 * @return
	 * @throws Exception
	 */
	public static List<EisNoticeBO> loadNoticeForBatchNO(Long batchNo)
			throws Exception {
		PreparedStatement pst = null;
		ResultSet rs = null;
		String sql = null;
		Connection conn = DBUtil.getConnection();
		List<EisNoticeBO> list = new ArrayList<EisNoticeBO>();
		try {
			sql = "SELECT n.NOTICE_ID,n.NOTICE_CATE,n.NOTICE_SOURCE,n.NOTICE_TITLE,n.NOTICE_CONTENT,n.SEND_USER,n.SEND_TIME,n.RECV_USER,n.RECV_TIME,n.REMARK,n.OPERATE_TYPE,n.RAW_SEQ_ID,n.SEND_USER_CATE,n.RECV_USER_CATE,n.SCHEDULE_SEND_TIME,n.SEND_USER_NAME,n.RECV_USER_NAME,n.BATCH_NO,n.NOTICE_FAVORITE,m.MSG_ID,m.NOTICE_ID,"
					+ "m.NOTICE_TITLE,m.NOTICE_CONTENT,m.MSG_SCHEDULE_TIME,m.SEND_USER_NAME,m.RECV_USER_NAME,m.MP,m.SEND_STATUS,m.SEND_TIME msgSendtime,m.CREATE_TIME,m.ORG_ID "
					+ "from EIS_NOTICE_INDIVID_MSG m right "
					+ "join EIS_NOTICE_INDIVID n on m.notice_id = n.notice_id "
					+ "where n.batch_no = ?";
			pst = conn.prepareStatement(sql);
			pst.setLong(1, batchNo);
			logger.info("batchNo=" + batchNo);
			rs = pst.executeQuery();
			EisNoticeBO bo = null;
			while (rs.next()) {
				bo = fetchAll(rs);
				if (null != bo) {
					list.add(bo);
				}
			}
		} catch (Exception e) {
			logger.error("EisNoticeIndividBean loadNoticeForBatchNO(batchNo="
					+ batchNo + ") Error", e);
			throw e;
		} finally {
			DBUtil.close(rs, pst, conn);
		}
		return list;
	}

	// 消息表字段信息
	private static EisNoticeBO fetch(ResultSet rs) throws Exception {
		EisNoticeBO bo = new EisNoticeBO();

		// 个人消息ID
		if (!isEmpty(rs.getString("NOTICE_ID"))) {
			bo.setNoticeId(Long.valueOf(rs.getString("NOTICE_ID")));
		} else {
			bo.setNoticeId(null);
		}

		// 消息类别
		if (!isEmpty(rs.getString("NOTICE_CATE"))) {
			bo.setNoticeCate(Long.valueOf(rs.getString("NOTICE_CATE")));
		} else {
			bo.setNoticeCate(null);
		}

		// 消息来源
		if (!isEmpty(rs.getString("NOTICE_SOURCE"))) {
			bo.setNoticeSource(Long.valueOf(rs.getString("NOTICE_SOURCE")));
		} else {
			bo.setNoticeSource(null);
		}

		// 消息主题
		bo.setNoticeTitle(rs.getString("NOTICE_TITLE"));
		// 消息内容
		bo.setNoticeContent(rs.getString("NOTICE_CONTENT"));
		// 发送人员
		if (!isEmpty(rs.getString("SEND_USER"))) {
			bo.setSendUser(rs.getString("SEND_USER"));
		} else {
			bo.setSendUser(null);
		}

		// 发送时间
		if (!isEmpty(rs.getTimestamp("SEND_TIME"))) {
			bo.setSendTime(rs.getTimestamp("SEND_TIME"));
		} else {
			bo.setSendTime(null);
		}
		// 接收人员
		if (!isEmpty(rs.getString("RECV_USER"))) {
			bo.setRecvUser(rs.getString("RECV_USER"));
		} else {
			bo.setRecvUser(null);
		}
		// 接收时间
		if (!isEmpty(rs.getTimestamp("RECV_TIME"))) {
			bo.setRecvTime(rs.getTimestamp("RECV_TIME"));
		} else {
			bo.setRecvTime(null);
		}
		// 备份
		if (!isEmpty(rs.getString("REMARK"))) {
			bo.setRemark(rs.getString("REMARK"));
		} else {
			bo.setRemark(null);
		}
		// 请求类型
		if (!isEmpty(rs.getString("OPERATE_TYPE"))) {
			bo.setOperateType(rs.getString("OPERATE_TYPE"));
		} else {
			bo.setOperateType(null);
		}
		// 发送流水
		if (!isEmpty(rs.getString("RAW_SEQ_ID"))) {
			bo.setRawSeqId(rs.getString("RAW_SEQ_ID"));
		} else {
			bo.setRawSeqId(null);
		}
		// 发送人类型
		if (!isEmpty(rs.getString("SEND_USER_CATE"))) {
			bo.setSendUserCate(rs.getString("SEND_USER_CATE"));
		} else {
			bo.setSendUserCate(null);
		}
		// 接收人类型
		if (!isEmpty(rs.getString("RECV_USER_CATE"))) {
			bo.setRecvUserCate(rs.getString("RECV_USER_CATE"));
		} else {
			bo.setRecvUserCate(null);
		}
		// 指定接收时间
		if (!isEmpty(rs.getTimestamp("SCHEDULE_SEND_TIME"))) {
			bo.setScheduleSendTime(rs.getTimestamp("SCHEDULE_SEND_TIME"));
		} else {
			bo.setScheduleSendTime(null);
		}
		// 发送人姓名
		if (!isEmpty(rs.getString("SEND_USER_NAME"))) {
			bo.setSendUserName(rs.getString("SEND_USER_NAME"));
		} else {
			bo.setSendUserName(null);
		}
		// 接收人姓名
		if (!isEmpty(rs.getString("RECV_USER_NAME"))) {
			bo.setRecvUserName(rs.getString("RECV_USER_NAME"));
		} else {
			bo.setRecvUserName(null);
		}
		// 消息批次号
		if (!isEmpty(rs.getString("BATCH_NO"))) {
			bo.setBatchNo(rs.getLong("BATCH_NO"));
		} else {
			bo.setBatchNo(null);
		}
		// 消息收藏
		if (!isEmpty(rs.getString("NOTICE_FAVORITE"))) {
			bo.setNoticeFavorite(rs.getString("NOTICE_FAVORITE"));
		} else {
			bo.setNoticeFavorite(null);
		}
		
		//消息标题说明
		if (!isEmpty(rs.getString("NOTICE_TITLE_DESC"))) {
			bo.setNoticeTitleDesc(rs.getString("NOTICE_TITLE_DESC"));
		} else {
			bo.setNoticeTitleDesc("");
		}
		
		//是否有详情
		if (!isEmpty(rs.getString("IS_HAVE_DETAILS"))) {
			bo.setIsHaveDetails(rs.getString("IS_HAVE_DETAILS"));
		} else {
			bo.setIsHaveDetails("");
		}		
		//是否需要通知
		if (!isEmpty(rs.getString("IS_NEED_INFORM"))) {
			bo.setIsNeedInform(rs.getString("IS_NEED_INFORM"));
		} else {
			bo.setIsNeedInform("");
		}
		if(!isEmpty(rs.getString("MUID"))){
			bo.setMuid(rs.getString("MUID"));
		}
		if(!isEmpty(rs.getString("IS_NEED_UPDATE"))){
			bo.setIsNeedUpdate(rs.getString("IS_NEED_UPDATE"));
		}
		if(!isEmpty(rs.getString("NOTIFICATION_TYPE"))){
			bo.setNotificationType(rs.getString("NOTIFICATION_TYPE"));
		}
		if(!isEmpty(rs.getString("NOTICE_DESC"))){
			bo.setNoticeDesc(rs.getString("NOTICE_DESC"));
		}
		return bo;
	}

	// 消息表+短信表的字段信息
	private static EisNoticeBO fetchAll(ResultSet rs) throws Exception {
		EisNoticeBO bo = new EisNoticeBO();

		// 个人消息ID
		if (!isEmpty(rs.getString("NOTICE_ID"))) {
			bo.setNoticeId(Long.valueOf(rs.getString("NOTICE_ID")));
		} else {
			bo.setNoticeId(null);
		}

		// 消息类别
		if (!isEmpty(rs.getString("NOTICE_CATE"))) {
			bo.setNoticeCate(Long.valueOf(rs.getString("NOTICE_CATE")));
		} else {
			bo.setNoticeCate(null);
		}

		// 消息来源
		if (!isEmpty(rs.getString("NOTICE_SOURCE"))) {
			bo.setNoticeSource(Long.valueOf(rs.getString("NOTICE_SOURCE")));
		} else {
			bo.setNoticeSource(null);
		}

		// 消息主题
		bo.setNoticeTitle(rs.getString("NOTICE_TITLE"));
		// 消息内容
		bo.setNoticeContent(rs.getString("NOTICE_CONTENT"));
		// 发送人员
		if (!isEmpty(rs.getString("SEND_USER"))) {
			bo.setSendUser(rs.getString("SEND_USER"));
		} else {
			bo.setSendUser(null);
		}

		// 发送时间
		if (!isEmpty(rs.getTimestamp("SEND_TIME"))) {
			bo.setSendTime(rs.getTimestamp("SEND_TIME"));
		} else {
			bo.setSendTime(null);
		}
		// 接收人员
		if (!isEmpty(rs.getString("RECV_USER"))) {
			bo.setRecvUser(rs.getString("RECV_USER"));
		} else {
			bo.setRecvUser(null);
		}
		// 接收时间
		if (!isEmpty(rs.getTimestamp("RECV_TIME"))) {
			bo.setRecvTime(rs.getTimestamp("RECV_TIME"));
		} else {
			bo.setRecvTime(null);
		}
		// 备份
		if (!isEmpty(rs.getString("REMARK"))) {
			bo.setRemark(rs.getString("REMARK"));
		} else {
			bo.setRemark(null);
		}
		// 请求类型
		if (!isEmpty(rs.getString("OPERATE_TYPE"))) {
			bo.setOperateType(rs.getString("OPERATE_TYPE"));
		} else {
			bo.setOperateType(null);
		}
		// 发送流水
		if (!isEmpty(rs.getString("RAW_SEQ_ID"))) {
			bo.setRawSeqId(rs.getString("RAW_SEQ_ID"));
		} else {
			bo.setRawSeqId(null);
		}
		// 发送人类型
		if (!isEmpty(rs.getString("SEND_USER_CATE"))) {
			bo.setSendUserCate(rs.getString("SEND_USER_CATE"));
		} else {
			bo.setSendUserCate(null);
		}
		// 接收人类型
		if (!isEmpty(rs.getString("RECV_USER_CATE"))) {
			bo.setRecvUserCate(rs.getString("RECV_USER_CATE"));
		} else {
			bo.setRecvUserCate(null);
		}
		// 指定接收时间
		if (!isEmpty(rs.getTimestamp("SCHEDULE_SEND_TIME"))) {
			bo.setScheduleSendTime(rs.getTimestamp("SCHEDULE_SEND_TIME"));
		} else {
			bo.setScheduleSendTime(null);
		}
		// 发送人姓名
		if (!isEmpty(rs.getString("SEND_USER_NAME"))) {
			bo.setSendUserName(rs.getString("SEND_USER_NAME"));
		} else {
			bo.setSendUserName(null);
		}
		// 接收人姓名
		if (!isEmpty(rs.getString("RECV_USER_NAME"))) {
			bo.setRecvUserName(rs.getString("RECV_USER_NAME"));
		} else {
			bo.setRecvUserName(null);
		}
		// 消息批次号
		if (!isEmpty(rs.getString("BATCH_NO"))) {
			bo.setBatchNo(rs.getLong("BATCH_NO"));
		} else {
			bo.setBatchNo(null);
		}
		// 消息收藏
		if (!isEmpty(rs.getString("NOTICE_FAVORITE"))) {
			bo.setNoticeFavorite(rs.getString("NOTICE_FAVORITE"));
		} else {
			bo.setNoticeFavorite(null);
		}

		// 短信ID
		if (!isEmpty(rs.getString("MSG_ID"))) {
			bo.setMsgId(Long.valueOf(rs.getString("MSG_ID")));
		} else {
			bo.setMsgId(null);
		}

		// 个人消息ID
		if (!isEmpty(rs.getString("NOTICE_ID"))) {
			bo.setNoticeId(Long.valueOf(rs.getString("NOTICE_ID")));
		} else {
			bo.setNoticeId(null);
		}

		// 消息主题
		bo.setNoticeTitle(rs.getString("NOTICE_TITLE"));
		// 消息内容
		bo.setNoticeContent(rs.getString("NOTICE_CONTENT"));

		// 短信计划发送时间，比消息计划发送时间多6小时
		if (!isEmpty(rs.getTimestamp("MSG_SCHEDULE_TIME"))) {
			bo.setMsgScheduleTime(rs.getTimestamp("MSG_SCHEDULE_TIME"));
		} else {
			bo.setMsgScheduleTime(null);
		}

		// 发送人姓名
		if (!isEmpty(rs.getString("SEND_USER_NAME"))) {
			bo.setSendUserName(rs.getString("SEND_USER_NAME"));
		} else {
			bo.setSendUserName(null);
		}
		// 接收人姓名
		if (!isEmpty(rs.getString("RECV_USER_NAME"))) {
			bo.setRecvUserName(rs.getString("RECV_USER_NAME"));
		} else {
			bo.setRecvUserName(null);
		}

		// 接收方手机号
		if (!isEmpty(rs.getString("MP"))) {
			bo.setMp(rs.getString("MP"));
		} else {
			bo.setMp(null);
		}

		// 短信状态
		if (!isEmpty(rs.getString("SEND_STATUS"))) {
			bo.setSendStatus(Long.valueOf(rs.getString("SEND_STATUS")));
		} else {
			bo.setSendStatus(null);
		}

		// 发送时间
		if (!isEmpty(rs.getTimestamp("msgSendtime"))) {
			bo.setMsgSendTime(rs.getTimestamp("msgSendtime"));
		} else {
			bo.setMsgSendTime(null);
		}

		// 创建时间
		if (!isEmpty(rs.getTimestamp("CREATE_TIME"))) {
			bo.setCreateTime(rs.getTimestamp("CREATE_TIME"));
		} else {
			bo.setCreateTime(null);
		}

		// 发送方机构id
		if (!isEmpty(rs.getString("ORG_ID"))) {
			bo.setOrgId(rs.getString("ORG_ID"));
		} else {
			bo.setOrgId(null);
		}

		return bo;
	}

	/**
	 * 批量更新个人消息接收时间
	 * 
	 * @param List
	 *            <String> list 消息的id号的集合
	 * @return
	 * @throws Exception
	 */
	public static void batchUpdateRecvTime(List<String> list) throws Exception {
		if (null == list || list.isEmpty()) {
			return;
		}
		PreparedStatement pst = null;
		PreparedStatement pst2 = null;
		String sql = null;
		String sql2 = null;
		Connection conn = null;
		try {
			conn = DBUtil.getConnection();
			sql = "update EIS_NOTICE_INDIVID set RECV_TIME = sysdate,OPERATE_TYPE='3' where NOTICE_ID = ?";
			sql2 = "update EIS_NOTICE_INDIVID_MSG set SEND_STATUS ='2' where NOTICE_ID = ?";
			pst = conn.prepareStatement(sql);
			pst2 = conn.prepareStatement(sql2);
			int i = 0;
			int j = list.size();
			for (; i < j; i++) {
				pst.setString(1, list.get(i));
				pst.addBatch();
				pst2.setString(1, list.get(i));
				pst2.addBatch();
			}
			pst.executeBatch();
			pst2.executeBatch();
		} catch (Exception e) {
			logger.error("EIS_NOTICE_INDIVID update  Error", e);
			throw e;
		} finally {
			DBUtil.close(null, pst, conn);
			DBUtil.close(null, pst2, conn);
		}
	}

	/**
	 * 批量更新个人消息接收时间
	 * 
	 * @param List
	 *            <String> list 消息的id号的集合
	 * @return
	 * @throws Exception
	 */
	public static void batchUpdateRecvTime(List<String> list, String recvUser)
			throws Exception {
		if (null == list || list.isEmpty()) {
			return;
		}
		PreparedStatement pst = null;
		PreparedStatement pst2 = null;
		String sql = null;
		String sql2 = null;
		Connection conn = null;
		try {
			conn = DBUtil.getConnection();
			sql = "update EIS_NOTICE_INDIVID set RECV_TIME = sysdate,OPERATE_TYPE='3' where NOTICE_ID = ? AND RECV_USER= ?";
			sql2 = "update EIS_NOTICE_INDIVID_MSG set SEND_STATUS ='2' where NOTICE_ID = ?";
			pst = conn.prepareStatement(sql);
			pst2 = conn.prepareStatement(sql2);
			int i = 0;
			int j = list.size();
			for (; i < j; i++) {
				pst.setString(1, list.get(i));
				pst.setString(2, recvUser);
				pst.addBatch();
				pst2.setString(1, list.get(i));
				pst2.addBatch();
			}
			pst.executeBatch();
			pst2.executeBatch();
		} catch (Exception e) {
			logger.error("EIS_NOTICE_INDIVID update  Error", e);
			throw e;
		} finally {
			DBUtil.close(null, pst, conn);
			DBUtil.close(null, pst2, conn);
		}
	}

	/**
	 * 消息回执--更改消息状态
	 * 
	 * @param noticeId
	 *            消息的id
	 * @param operateType
	 *            消息的请求类型 1-新建 2-撤销 3-阅读
	 * @return
	 * @throws Exception
	 */
	public static int updateNoticeOperateType(Long noticeId, String operateType)
			throws Exception {
		int rows = -1;
		if (null == noticeId) {
			return rows = 0;
		}
		logger.debug("update Notice Operate Type ");
		Connection conn = null;
		PreparedStatement ps = null;
		try {
			conn = DBUtil.getConnection();
			String sql = "update EIS_NOTICE_INDIVID set OPERATE_TYPE = ? where NOTICE_ID = ?";
			ps = conn.prepareStatement(sql);
			ps.setString(1, operateType);
			ps.setLong(2, noticeId);
			rows = ps.executeUpdate();
		} catch (Exception e) {
			logger.error(" EIS_NOTICE_INDIVID update OPERATE_TYPE Error!!"
					+ e.getMessage());
			throw e;
		} finally {
			DBUtil.close(null, ps, conn);
		}
		return rows;
	}

	/**
	 * 根据消息的发送流水修改请求类型
	 * 
	 * @param rawSeqId
	 *            消息的发送流水
	 * @param operateType
	 *            消息的请求类型 1-新建 2-撤销 3-阅读
	 * @return
	 * @throws Exception
	 */
	public static int uptOprTypeByRawSeqId(String rawSeqId, String operateType)
			throws Exception {
		int rows = -1;
		if (null == rawSeqId) {
			return rows = 0;
		}
		Connection conn = null;
		PreparedStatement ps = null;
		try {
			conn = DBUtil.getConnection();
			String sql = "update EIS_NOTICE_INDIVID set OPERATE_TYPE = ? where OPERATE_TYPE = 1 AND RAW_SEQ_ID = ?";
			ps = conn.prepareStatement(sql);
			ps.setString(1, operateType);
			ps.setString(2, rawSeqId);
			rows = ps.executeUpdate();
		} catch (Exception e) {
			logger.error(" EIS_NOTICE_INDIVID update OPERATE_TYPE Error!!"
					+ e.getMessage());
			throw e;
		} finally {
			DBUtil.close(null, ps, conn);
		}
		return rows;
	}

	/**
	 * 批量删除消息
	 * 
	 * @param list
	 * @return
	 * @throws Exception
	 */
	public static void batchDeleteNotice(String type, List<String> list)
			throws Exception {
		if (null == list || list.isEmpty()) {
			return;
		}
		PreparedStatement pst = null;
		String sql = null;
		Connection conn = null;
		try {
			conn = DBUtil.getConnection();
			if ("0".equals(type)) {
				sql = "DELETE FROM  EIS_NOTICE_BOARD WHERE NOTICE_ID = ?";
			} else {
				sql = "DELETE FROM  EIS_NOTICE_INDIVID WHERE NOTICE_ID = ?";
			}
			pst = conn.prepareStatement(sql);
			int i = 0;
			int j = list.size();
			for (; i < j; i++) {
				pst.setString(1, list.get(i));
				pst.addBatch();
			}
			pst.executeBatch();
		} catch (Exception e) {
			logger.error("batchDeleteNotice  Error type=" + type, e);
			throw e;
		} finally {
			DBUtil.close(null, pst, conn);
		}
	}

	private static boolean isEmpty(Object oj) {
		if (null == oj || "".equals(oj)) {
			return true;
		} else {
			return false;
		}
	}

	/**
	 * 根据主键修改消息的收藏锁定
	 * 
	 * @param noticeId
	 * @param favorite
	 * @return
	 * @throws Exception
	 */
	public static int updateNoticeFavoriteType(Long noticeId, String favorite)
			throws Exception {
		int rows = -1;
		if (null == noticeId) {
			return rows = 0;
		}
		logger.debug("update noticeFavorite ");
		Connection conn = null;
		PreparedStatement ps = null;
		try {
			conn = DBUtil.getConnection();
			String sql = "update EIS_NOTICE_INDIVID set NOTICE_FAVORITE = ? where NOTICE_ID = ?";
			ps = conn.prepareStatement(sql);
			ps.setString(1, favorite);
			ps.setLong(2, noticeId);
			rows = ps.executeUpdate();
		} catch (Exception e) {
			logger.error(" EIS_NOTICE_INDIVID update noticeFavorite Error!!"
					+ e.getMessage());
			throw e;
		} finally {
			DBUtil.close(null, ps, conn);
		}
		return rows;
	}

	/**
	 * 根据muid查询 发送时间(消息入库的时间) >= lastNoticeSendTime 的消息
	 * @param muid
	 * @param lastNoticeSendTime
	 * @return
	 */
	public static List<EisNoticeBO> loadAllByMUID(String muid, Timestamp lastNoticeSendTime) throws Exception {
		PreparedStatement pst = null;
		ResultSet rs = null;
		String sql = null;
		Connection conn = null;
		List<EisNoticeBO> noticeBOList = new ArrayList<EisNoticeBO>();
		try {
			sql = "SELECT T.NOTICE_ID, T.NOTICE_CATE, T.NOTICE_SOURCE, T.NOTICE_TITLE, T.NOTICE_CONTENT, T.SEND_USER, T.SEND_TIME, T.RECV_USER, T.RECV_TIME, T.REMARK, T.OPERATE_TYPE, T.RAW_SEQ_ID, T.SEND_USER_CATE, T.RECV_USER_CATE, T.SCHEDULE_SEND_TIME, T.SEND_USER_NAME, T.RECV_USER_NAME, T.BATCH_NO, T.NOTICE_FAVORITE, T.NOTICE_TITLE_DESC, T.IS_HAVE_DETAILS, T.IS_NEED_INFORM, T.MUID, T.IS_NEED_UPDATE, T.NOTIFICATION_TYPE, T.NOTICE_DESC "+
					" from EIS_NOTICE_INDIVID T " +
					" where T.SCHEDULE_SEND_TIME <= sysdate AND T.SEND_TIME >= ? AND T.MUID = ? " +
					" ORDER BY SEND_TIME desc ";
			conn = DBUtil.getConnection();
			pst = conn.prepareStatement(sql);
			pst.setTimestamp(1, lastNoticeSendTime);
			pst.setString(2, muid);
			rs = pst.executeQuery();
			EisNoticeBO bo = null;
			while (rs.next()) {
				bo = fetch(rs);
				if (null != bo) {
					noticeBOList.add(bo);
				}
			}
		} catch (Exception e) {
			logger.error("EisNoticeIndividBean loadAllByMUID(muid=" + muid + ", lastNoticeSendTime=" + lastNoticeSendTime + ")", e);
			throw e;
		} finally {
			DBUtil.close(rs, pst, conn);
		}
		return noticeBOList;
	}

	public static List<EisNoticeIntervalBO> listIntervalTime(int noticeSource) throws SQLException {
		Connection conn = null;
		PreparedStatement pst = null;
		ResultSet rs = null;
		String sql = null;
		List<EisNoticeIntervalBO> intervalBOList = null;
		try {
			sql = "select t.notice_source, start_time, end_time, interval_time, show_order from EIS_NOTICE_QUERY_INTERVAL t " +
					" where t.NOTICE_SOURCE = ? order by t.SHOW_ORDER";
			conn = DBUtil.getConnection();
			pst = conn.prepareStatement(sql);
			pst.setInt(1, noticeSource);
			rs = pst.executeQuery();
			intervalBOList = new ArrayList<EisNoticeIntervalBO>();
			EisNoticeIntervalBO intervalBO = null;
			while (rs.next()){
				intervalBO = new EisNoticeIntervalBO();
				intervalBO.setNoticeSource((long) noticeSource);
				intervalBO.setStartTime(rs.getLong("start_time"));
				intervalBO.setEndTime(rs.getLong("end_time"));
				intervalBO.setIntervalTime(rs.getLong("interval_time"));
				intervalBO.setShowOrder(rs.getInt("show_order"));
				intervalBOList.add(intervalBO);
			}
		} catch (SQLException e) {
			logger.error("EisNoticeIndividBean.listIntervalTime, noticeSource="+noticeSource, e);
			throw e;
		} finally {
			DBUtil.close(rs, pst, conn);
		}
		return intervalBOList;
	}

    public static int updateNoticeOperateType(List noticeIdList, String operateType, Date updateTime) throws Exception {
        int rows = 0;
        if (null == noticeIdList) {
            return rows = 0;
        }
        Connection conn = null;
        PreparedStatement ps = null;
        try {
            conn = DBUtil.getConnection();
            String sql = "update EIS_NOTICE_INDIVID set OPERATE_TYPE = ?, IS_NEED_UPDATE = '1', SEND_TIME = ? where NOTICE_ID = ?";
            ps = conn.prepareStatement(sql);
            for (Object noticeId : noticeIdList) {
                ps.setString(1, operateType);
                ps.setTimestamp(2, new Timestamp(updateTime.getTime()));
                ps.setLong(3, Long.valueOf(noticeId.toString()));
                ps.addBatch();
            }
            int[] resultRows = ps.executeBatch();
            for (int resultRow : resultRows) {
            	if(resultRow > 0 || resultRow == Statement.SUCCESS_NO_INFO){
					rows++;
				}
            }
        } catch (Exception e) {
            logger.error(" EIS_NOTICE_INDIVID update OPERATE_TYPE Error! noticeIdList="+noticeIdList, e);
            throw e;
        } finally {
            DBUtil.close(null, ps, conn);
        }
        return rows;
    }

}
