package com.cntaiping.intserv.enotice.message;

import java.util.List;

import com.cntaiping.intserv.basic.util.exception.Errors;
import com.cntaiping.intserv.enotice.bmodel.EisNoticeBoard;
import com.cntaiping.intserv.enotice.bmodel.EisNoticeIndivid;
import com.cntaiping.mobile.basic.ResultBO;

/**
 * 远程访问消息接口
 * 
 * @author ZhangMingxue
 * @version 1.0
 * @time 2013上午10:34:47
 * @JDK 1.6
 */
public interface MessageRemote {
	/**
	 * 创建广播消息
	 * 
	 * @param enb
	 *            EisNoticeBoard BO对象
	 * @return
	 */
	public Errors createBoardMessage(EisNoticeBoard enb);

	/**
	 * 批量创建广播消息
	 * 
	 * @param enb
	 *            EisNoticeBoard对象的集合
	 * @return
	 */
	@SuppressWarnings("unchecked")
	public Errors createBatchBoardMessage(List enbList);

	/**
	 * 创建个人消息
	 * 
	 * @param eni
	 *            EisNoticeIndivid BO对象
	 * @return
	 */
	public Errors createIndividMessage(EisNoticeIndivid eni);

	/**
	 * 批量创建个人消息
	 * 
	 * @param eni
	 *            EisNoticeIndivid对象的集合
	 * @return
	 */
	@SuppressWarnings("unchecked")
	public Errors createBatchIndividMessage(List eniList);

	/**
	 * 修改发送消息
	 * 
	 * Long batchNo 消息批次号 int type 消息发送类型 1：消息 2：短信
	 * 
	 * @param eni
	 *            EisNoticeIndivid对象的集合
	 * @return
	 */
	@SuppressWarnings("unchecked")
	public Errors updateIndividMessage(Long batchNo, int type, List eniList);

	/***
	 * 创建用户新增接口(查看用户已读未读) eis_notice_board_user
	 * 
	 * @throws Exception
	 */
	public ResultBO createBoardUser(String noticeid, String userid) throws Exception;

	/**
	 * 保存个人消息
	 * @param individNotice 个人消息
	 * @return 响应结果
	 */
	public ResultBO saveIndividNotice(EisNoticeIndivid individNotice);

	/**
	 * 批量创建个人消息
	 * @param individNoticeList 个人消息集合
	 * @return 响应结果
	 */
	public ResultBO saveBatchIndividNotice(List<EisNoticeIndivid> individNoticeList);

	/**
	 * 更新个人消息数据
	 * 查询字段(必须)：noticeId, muid
	 * 更新字段(非必须)：noticeTitle, noticeContent,noticeTitleDesc
	 * @param individNotice 个人消息()
	 * @return 错误信息，errorCode = -1 代表无错误
	 */
	public Errors updateIndividNotice(EisNoticeIndivid individNotice);

	/**
	 * 批量更新个人消息数据
	 * 查询字段(必须)：noticeId, muid
	 * 更新字段(非必须)：noticeTitle, noticeContent,noticeTitleDesc
	 * @param individNoticeList 个人消息
	 * @return 错误信息，errorCode = -1 代表无错误
	 */
	public Errors updateBatchIndividNotice(List<EisNoticeIndivid> individNoticeList);

}
